==> xl-react-components-0.16.62.tgz: package/app/xl-react-buttons/xl-react-button-with-dropdown/xl-react-button-dropdown-item.js <==
import React, {PureComponent} from 'react';
import R from 'ramda';
import RS from 'ramdasauce';
import PropTypes from 'prop-types';
import {MenuItem} from 'react-bootstrap';
import {clearTimeouts, delayedHandler} from '../xl-react-button-utils';

export class XlReactButtonDropdownItem extends PureComponent {
    static propTypes = {
        action: PropTypes.func.isRequired,
        disabled: PropTypes.bool,
        header: PropTypes.bool,
        inactiveTime: PropTypes.number,
        label: PropTypes.string.isRequired,
        labelRenderer: PropTypes.func,
        onSelect: PropTypes.func,
        separator: PropTypes.bool
    };

    static defaultProps = {disabled: false, inactiveTime: 500};

    state = {clickable: true};

    componentWillMount() {
        this.timeouts = [];
    }

    componentWillUnmount() {
        clearTimeouts(this.timeouts);
    }

    handleClick = (event) => {
        if (!this.props.disabled) {
            delayedHandler(this, 'action', event);
            this.props.onSelect(false);
        }
    };

    render() {
        const {disabled, header, label, labelRenderer, separator} = this.props;
        const renderChildren = R.cond([
            [RS.isNilOrEmpty, R.always(R.or(labelRenderer, label))],
            [R.T, R.always(null)]
        ]);

        return <MenuItem
            disabled={disabled}
            divider={separator}
            eventKey={label}
            header={header}
            key={label}
            onClick={this.handleClick}>{renderChildren(separator)}
        </MenuItem>;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-buttons/xl-react-button-with-dropdown/xl-react-button-dropdown-item.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import {MenuItem} from 'react-bootstrap';
import {nextId} from '../../utils/id-generator';
import {clearTimeouts, delayedHandler, labelToClassName} from '../xl-react-button-utils';

export class XlReactButtonDropdownItem extends PureComponent {
    static propTypes = {
        action: PropTypes.func.isRequired,
        disabled: PropTypes.bool,
        header: PropTypes.bool,
        inactiveTime: PropTypes.number,
        labelRenderer: PropTypes.func,
        onSelect: PropTypes.func,
        separator: PropTypes.bool
    };

    static defaultProps = {disabled: false, inactiveTime: 500};

    state = {clickable: true};

    componentWillMount() {
        this.eventKey = nextId();
        this.timeouts = [];
    }

    componentWillUnmount() {
        clearTimeouts(this.timeouts);
    }

    handleClick = (event) => {
        if (!this.props.disabled) {
            delayedHandler(this, 'action', event);
            this.props.onSelect(false);
        }
    };

    render() {
        const {disabled, header, labelRenderer, separator} = this.props;
        const renderChildren = (sep) => sep ? null : labelRenderer();
        const displayedElement = renderChildren(separator);

        return <MenuItem
            className={labelToClassName(displayedElement)}
            disabled={disabled}
            divider={separator}
            eventKey={this.eventKey}
            header={header}
            key={this.eventKey}
            onClick={this.handleClick}>{displayedElement}
        </MenuItem>;
    }
}
